import { Component, Host, h, Prop, State, Watch } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
import { formatName, shorten } from '../../utils/string';
/**
 * A participant entry component used inside `dyte-participants` which shows data like:
 * name, picture and media device status.
 *
 * You can perform privileged actions on the participant too.
 */
export class DyteParticipant {
  constructor() {
    this.pinnedListener = ({ isPinned }) => {
      this.isPinned = isPinned;
    };
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.audioEnabled = false;
    this.videoEnabled = false;
    this.isPinned = false;
    this.canDisableParticipantAudio = false;
    this.canDisableParticipantVideo = false;
    this.canKickParticipant = false;
    this.canPinParticipant = false;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
    this.participantChanged(this.participant);
  }
  disconnectedCallback() {
    if (this.participant == null)
      return;
    this.audioUpdateListener &&
      this.participant.removeListener('audioUpdate', this.audioUpdateListener);
    this.videoUpdateListener &&
      this.participant.removeListener('videoUpdate', this.videoUpdateListener);
    this.participant.removeListener('pinned', this.pinnedListener);
    this.participant.removeListener('unpinned', this.pinnedListener);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.canDisableParticipantAudio = meeting.self.permissions.canAllowParticipantAudio;
      this.canDisableParticipantVideo = meeting.self.permissions.canAllowParticipantVideo;
      this.canKickParticipant = meeting.self.permissions.kickParticipant;
      this.canPinParticipant = meeting.self.permissions.pinParticipant;
    }
  }
  participantChanged(participant) {
    if (participant != null) {
      this.audioEnabled = participant.audioEnabled;
      this.videoEnabled = participant.videoEnabled;
      this.isPinned = participant.isPinned;
      this.audioUpdateListener = ({ audioEnabled }) => {
        this.audioEnabled = audioEnabled;
      };
      this.videoUpdateListener = ({ videoEnabled }) => {
        this.videoEnabled = videoEnabled;
      };
      participant.addListener('audioUpdate', this.audioUpdateListener);
      participant.addListener('videoUpdate', this.videoUpdateListener);
      participant.addListener('pinned', this.pinnedListener);
      participant.addListener('unpinned', this.pinnedListener);
    }
  }
  render() {
    var _a, _b;
    const showMenu = this.canDisableParticipantAudio || this.canDisableParticipantVideo || this.canKickParticipant;
    const name = formatName(((_a = this.participant) === null || _a === void 0 ? void 0 : _a.name) || '');
    return (h(Host, null,
      h("div", { class: "left" },
        h("dyte-avatar", { participant: this.participant, size: "sm" }),
        h("p", { class: "name", title: name },
          shorten(name, 16),
          " ",
          ((_b = this.meeting) === null || _b === void 0 ? void 0 : _b.self.id) === this.participant.id && this.t('(you)'))),
      h("div", { class: "right" },
        h("dyte-icon", { class: {
            red: !this.audioEnabled,
          }, icon: this.audioEnabled ? this.iconPack.mic_on : this.iconPack.mic_off }),
        h("dyte-icon", { class: {
            red: !this.videoEnabled,
          }, icon: this.videoEnabled ? this.iconPack.video_on : this.iconPack.video_off }),
        showMenu && (h("dyte-menu", null,
          h("dyte-button", { variant: "ghost", kind: "icon", slot: "trigger" },
            h("dyte-icon", { class: "more", icon: this.iconPack.more_vertical })),
          h("dyte-menu-list", null,
            this.canPinParticipant && (h("dyte-menu-item", { onClick: () => {
                if (this.isPinned) {
                  this.participant.unpin();
                }
                else {
                  this.participant.pin();
                }
              } },
              h("dyte-icon", { icon: this.isPinned ? this.iconPack.pin_off : this.iconPack.pin, slot: "start" }),
              this.isPinned ? this.t('Unpin') : this.t('Pin'))),
            this.canDisableParticipantAudio && (h("dyte-menu-item", { onClick: () => {
                var _a, _b;
                (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.participants.disableAudio((_b = this.participant) === null || _b === void 0 ? void 0 : _b.id);
              } },
              h("dyte-icon", { icon: this.iconPack.mic_off, slot: "start" }),
              "Mute")),
            this.canDisableParticipantAudio && (h("dyte-menu-item", { onClick: () => {
                var _a, _b;
                (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.participants.disableVideo((_b = this.participant) === null || _b === void 0 ? void 0 : _b.id);
              } },
              h("dyte-icon", { icon: this.iconPack.video_off, slot: "start" }),
              "Turn off Video")),
            this.canKickParticipant && (h("dyte-menu-item", { class: "red", onClick: () => {
                var _a, _b;
                (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.participants.kick((_b = this.participant) === null || _b === void 0 ? void 0 : _b.id);
              } },
              h("dyte-icon", { icon: this.iconPack.dismiss, slot: "start" }),
              "Kick"))))))));
  }
  static get is() { return "dyte-participant"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-participant.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-participant.css"]
  }; }
  static get properties() { return {
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "participant": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Peer",
        "resolved": "({ readonly id: string; readonly name: string; readonly picture: string; readonly clientSpecificId: any; readonly waitlistStatus: \"accepted\" | \"waiting\" | \"rejected\" | \"none\"; readonly preview: Pick<LocalMediaHandler, \"audioTrack\" | \"videoTrack\" | \"audioEnabled\" | \"videoEnabled\">; readonly role: any; readonly userId: string; readonly organizationId: string; readonly supportsRemoteControl: boolean; readonly device: DeviceConfig; readonly audioTrack: MediaStreamTrack; readonly rawAudioTrack: MediaStreamTrack; readonly addAudioMiddleware: (audioMiddleware: AudioMiddleware) => Promise<{ success: boolean; message: string; }>; readonly removeAudioMiddleware: (audioMiddleware: AudioMiddleware) => Promise<{ success: boolean; message: string; }>; readonly videoTrack: MediaStreamTrack; readonly rawVideoTrack: MediaStreamTrack; readonly addVideoMiddleware: (videoMiddleware: VideoMiddleware) => Promise<{ success: boolean; message: string; }>; readonly removeVideoMiddleware: (videoMiddleware: VideoMiddleware) => Promise<{ success: boolean; message: string; }>; readonly screenShareTracks: { audio?: MediaStreamTrack; video?: MediaStreamTrack; }; readonly audioEnabled: boolean; readonly videoEnabled: boolean; readonly screenShareEnabled: boolean; readonly mediaPermissions: { audio?: \"NOT_REQUESTED\" | \"ACCEPTED\" | \"DENIED\" | \"SYSTEM_DENIED\" | \"COULD_NOT_START\"; video?: \"NOT_REQUESTED\" | \"ACCEPTED\" | \"DENIED\" | \"SYSTEM_DENIED\" | \"COULD_NOT_START\"; screenshare?: \"NOT_REQUESTED\" | \"ACCEPTED\" | \"DENIED\" | \"SYSTEM_DENIED\" | \"COULD_NOT_START\"; }; readonly permissions: DytePermissionsPreset | DytePermissionsPresetV1; readonly suggestedTheme: DyteThemePresetV1 | DyteThemePreset; readonly roomJoined: boolean; readonly setName: (name: string) => void; readonly setupTracks: (options?: { video?: boolean; audio?: boolean; }) => Promise<void>; readonly enableAudio: () => Promise<void>; readonly enableVideo: () => Promise<void>; readonly enableScreenShare: () => Promise<void>; readonly disableAudio: () => Promise<void>; readonly disableVideo: () => Promise<void>; readonly disableScreenShare: () => Promise<void>; readonly enablePreview: (options?: { audio?: boolean; video?: boolean; }) => Promise<void>; readonly disablePreview: (options?: { audio?: boolean; video?: boolean; }) => Promise<void>; readonly getCurrentDevices: () => { audio: MediaDeviceInfo; video: MediaDeviceInfo; speaker: MediaDeviceInfo; }; readonly getAudioDevices: () => MediaDeviceInfo[]; readonly getVideoDevices: () => MediaDeviceInfo[]; readonly getSpeakerDevices: () => MediaDeviceInfo[]; readonly getDeviceById: (deviceId: string, kind: \"audio\" | \"video\" | \"speaker\") => MediaDeviceInfo; readonly getAllDevices: () => MediaDeviceInfo[]; readonly setIsPinned: (isPinned: boolean, emitEvent?: boolean) => void; readonly isPinned: boolean; readonly pin: () => Promise<WebsocketMessage>; readonly unpin: () => Promise<WebsocketMessage>; readonly setDevice: (device: MediaDeviceInfo, preview?: boolean) => Promise<void>; readonly emit: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", ...args: any[]) => boolean; readonly on: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => void) => DyteSelf; readonly addListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly off: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly once: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly prependListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly prependOnceListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly removeListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteSelf; readonly removeAllListeners: (event?: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => DyteSelf; readonly listeners: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => Function[]; readonly listenerCount: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => number; readonly setMaxListeners: (n: number) => DyteSelf; readonly getMaxListeners: () => number; readonly rawListeners: (eventName: string | symbol) => Function[]; readonly eventNames: () => (string | symbol)[]; }) | ({ readonly id: string; readonly userId: string; readonly name: string; readonly picture: string; readonly isHost: boolean; readonly clientSpecificId?: string; readonly flags: { [key: string]: string | boolean; }; readonly device: DeviceConfig; readonly videoTrack: MediaStreamTrack; readonly audioTrack: MediaStreamTrack; readonly screenShareTracks: { audio: MediaStreamTrack; video: MediaStreamTrack; }; readonly videoEnabled: boolean; readonly audioEnabled: boolean; readonly screenShareEnabled: boolean; readonly supportsRemoteControl: boolean; readonly setVideoEnabled: (videoEnabled: boolean, emitEvent?: boolean) => void; readonly setAudioEnabled: (audioEnabled: boolean, emitEvent?: boolean) => void; readonly setScreenShareEnabled: (screenShareEnabled: boolean, emitEvent?: boolean) => void; readonly pin: () => Promise<WebsocketMessage>; readonly unpin: () => Promise<WebsocketMessage>; readonly setIsPinned: (isPinned: boolean, emitEvent?: boolean) => void; readonly disableAudio: () => Promise<void>; readonly kick: () => Promise<void>; readonly disableVideo: () => Promise<void>; readonly isPinned: boolean; readonly emit: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", ...args: any[]) => boolean; readonly on: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => void) => DyteParticipant; readonly addListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly off: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly once: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly prependListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly prependOnceListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly removeListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\", callback: (...args: any[]) => any) => DyteParticipant; readonly removeAllListeners: (event?: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => DyteParticipant; readonly listeners: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => Function[]; readonly listenerCount: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"cleared\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"waitlisted\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsCleared\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\" | \"pinned\" | \"unpinned\" | \"recordingUpdate\" | \"remoteRequestAdd\" | \"remoteRequestRemove\" | \"remoteUpdate\" | \"closed\" | \"ready\" | \"mediaPermissionError\" | \"broadcastedMessage\") => number; readonly setMaxListeners: (n: number) => DyteParticipant; readonly getMaxListeners: () => number; readonly rawListeners: (eventName: string | symbol) => Function[]; readonly eventNames: () => (string | symbol)[]; })",
        "references": {
          "Peer": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Participant object"
      }
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ people: string; chat: string; poll: string; participants: string; rocket: string; call_end: string; share: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_down: string; chevron_up: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; full_screen_maximize: string; full_screen_minimize: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; vertical_scroll_disabled: string; image_off: string; disconnected: string; wand: string; recording: string; subtract: string; stop_recording: string; warning: string; pin: string; pin_off: string; spinner: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "audioEnabled": {},
    "videoEnabled": {},
    "isPinned": {},
    "canDisableParticipantAudio": {},
    "canDisableParticipantVideo": {},
    "canKickParticipant": {},
    "canPinParticipant": {}
  }; }
  static get watchers() { return [{
      "propName": "meeting",
      "methodName": "meetingChanged"
    }, {
      "propName": "participant",
      "methodName": "participantChanged"
    }]; }
}
