import { proxyCustomElement, HTMLElement, writeTask, h, Host } from '@stencil/core/internal/client';
import { R as RemoteUpdateType } from './dyte-client.js';
import { l as loglevel } from './logger.js';
import { f as formatName, s as shorten } from './string.js';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { s as state } from './store.js';
import { d as defineCustomElement$4 } from './dyte-button2.js';
import { d as defineCustomElement$3 } from './dyte-icon2.js';
import { d as defineCustomElement$2 } from './dyte-notification2.js';

const SOUNDS = {
  joined: 'https://dyte-uploads.s3.ap-south-1.amazonaws.com/notification_join.mp3',
  message: 'https://dyte-uploads.s3.ap-south-1.amazonaws.com/notification_message.mp3',
};
/**
 * Handles notification sounds in a meeting
 */
class DyteNotificationsAudio {
  constructor() {
    this.audio = document.createElement('audio');
    this.audio.volume = 0.3;
  }
  play(sound, duration = 3000) {
    var _a;
    if (this.playing)
      return;
    this.playing = true;
    this.audio.src = SOUNDS[sound];
    this.audio.volume = 0.3;
    (_a = this.audio.play()) === null || _a === void 0 ? void 0 : _a.catch((err) => {
      loglevel.error('[dyte-notifications] play() failed\n', { sound, duration }, err);
    });
    setTimeout(() => {
      this.playing = false;
    }, duration);
  }
  async setDevice(id) {
    var _a, _b, _c;
    await ((_c = (_b = (_a = this.audio) === null || _a === void 0 ? void 0 : _a.setSinkId) === null || _b === void 0 ? void 0 : _b.call(_a, id)) === null || _c === void 0 ? void 0 : _c.catch((err) => {
      loglevel.error('[dyte-notifications] setSinkId() error\n', err);
    }));
  }
}

const dyteNotificationsCss = ":host{position:absolute;top:var(--dyte-space-4, 16px);right:var(--dyte-space-4, 16px);bottom:var(--dyte-space-4, 16px);left:var(--dyte-space-4, 16px);top:auto;z-index:10;display:flex;flex-direction:column;font-family:var(--dyte-font-family, sans-serif);pointer-events:none}dyte-notification{margin-top:var(--dyte-space-2, 8px)}";

const DyteNotifications$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.notificationPermissions = {
      participant_joined: false,
      participant_left: false,
      chat: false,
      polls: true,
    };
    this.soundPermissions = {
      participant_joined: false,
      participant_left: false,
      chat: false,
      polls: true,
    };
    /** Language */
    this.t = useLanguage();
    /** Icon pack */
    this.iconPack = defaultIconPack;
    this.notifications = [];
    this.onRemoteUpdate = ({ payload, type }) => {
      if (type === RemoteUpdateType.INCOMING_REQUEST_ACCEPTED) {
        let remotePeer = this.meeting.participants.joined.get(payload.request.remotePeerId);
        this.add({
          id: `message-${Math.random().toString(36)}`,
          icon: this.iconPack.chat,
          message: `Granted remote control to ${remotePeer.name}`,
          duration: 2000,
        });
      }
      if (type === RemoteUpdateType.OUTGOING_REQUEST_ACCEPTED) {
        let hostPeer = this.meeting.participants.joined.get(payload.request.hostPeerId);
        this.add({
          id: `message-${Math.random().toString(36)}`,
          icon: this.iconPack.chat,
          message: `${hostPeer.name} has granted remote control.`,
          duration: 2000,
        });
      }
      if (type === RemoteUpdateType.REQUEST_RECEIVED) {
        let remotePeer = this.meeting.participants.joined.get(payload.request.remotePeerId);
        this.add({
          id: `message-${Math.random().toString(36)}`,
          icon: this.iconPack.chat,
          message: `${remotePeer.name} has requested for remote control.`,
          duration: 2000,
        });
      }
      if (type === RemoteUpdateType.INCOMING_REQUEST_ENDED ||
        type === RemoteUpdateType.OUTGOING_REQUEST_ENDED) {
        this.add({
          id: `message-${Math.random().toString(36)}`,
          icon: this.iconPack.chat,
          message: `Existing remote control has been terminated.`,
          duration: 2000,
        });
      }
      if (type === RemoteUpdateType.REQUEST_SENT) {
        let hostPeer = this.meeting.participants.joined.get(payload.request.hostPeerId);
        this.add({
          id: `message-${Math.random().toString(36)}`,
          icon: this.iconPack.chat,
          message: `Sent remote control request to ${hostPeer.name}`,
          duration: 2000,
        });
      }
    };
    this.onDyteNotification = (e) => {
      this.add(e.detail);
    };
  }
  connectedCallback() {
    if (typeof document !== 'undefined') {
      document === null || document === void 0 ? void 0 : document.addEventListener('dyteNotification', this.onDyteNotification);
    }
    this.meetingChanged(this.meeting);
    this.configChanged(this.config);
  }
  disconnectedCallback() {
    if (typeof document !== 'undefined') {
      document === null || document === void 0 ? void 0 : document.removeEventListener('dyteNotification', this.onDyteNotification);
    }
    if (this.meeting == null)
      return;
    this.participantJoinedListener &&
      this.meeting.participants.joined.removeListener('participantJoined', this.participantJoinedListener);
    this.participantLeftListener &&
      this.meeting.participants.joined.removeListener('participantLeft', this.participantLeftListener);
    this.chatUpdateListener &&
      this.meeting.chat.removeListener('chatUpdate', this.chatUpdateListener);
    this.pollUpdateListener &&
      this.meeting.polls.removeListener('pollsUpdate', this.pollUpdateListener);
    this.networkUpdateListener &&
      this.meeting.meta.removeListener('disconnected', this.networkUpdateListener);
    this.networkUpdateListener &&
      this.meeting.meta.removeListener('connected', this.networkUpdateListener);
    this.meeting.remote.removeListener('remoteUpdate', this.onRemoteUpdate);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.audio = new DyteNotificationsAudio();
      this.participantJoinedListener = (participant) => {
        if (this.notificationPermissions.participant_joined) {
          this.add({
            id: `${participant.id}-joined`,
            message: `${formatName(participant.name)} just joined`,
            image: participant.picture,
            duration: 2100,
          });
        }
        if (this.soundPermissions.participant_joined && this.canPlayParticipantJoinedSound()) {
          this.audio.play('joined');
        }
      };
      this.participantLeftListener = (participant) => {
        if (this.notificationPermissions.participant_left) {
          this.add({
            id: `${participant.id}-left`,
            message: `${formatName(participant.name)} left`,
            image: participant.picture,
            duration: 2100,
          });
        }
      };
      this.chatUpdateListener = ({ message }) => {
        if (message != null) {
          if (message.userId === meeting.self.userId) {
            return;
          }
          if (message.type === 'text') {
            if (this.notificationPermissions.chat) {
              this.add({
                id: `message-${Math.random().toString(36)}`,
                icon: this.iconPack.chat,
                message: `${message.displayName}: ${shorten(message.message, 20)}`,
                duration: 2000,
              });
            }
            if (this.soundPermissions.chat && this.canPlayChatSound()) {
              this.audio.play('message');
            }
          }
        }
      };
      this.pollUpdateListener = ({ polls }) => {
        if (this.notificationPermissions.polls &&
          this.meeting.self.userId !== polls[polls.length - 1].createdByUserId) {
          this.add({
            id: `poll-${Math.random().toString(36)}`,
            icon: this.iconPack.poll,
            message: `New poll created by ${polls[polls.length - 1].createdBy}`,
            duration: 2000,
          });
        }
        if (this.soundPermissions.polls &&
          this.meeting.self.userId !== polls[polls.length - 1].createdByUserId &&
          this.canPlayChatSound()) {
          this.audio.play('message');
        }
      };
      this.deviceUpdateListener = ({ device, preview }) => {
        if (preview)
          return;
        if (device.kind === 'audiooutput') {
          this.audio.setDevice(device.deviceId);
        }
      };
      this.networkUpdateListener = ({ event }) => {
        this.remove('network');
        let reconnectDuration;
        if (event === 'disconnected') {
          reconnectDuration = 20000;
          this.add({
            id: 'network',
            icon: this.iconPack.disconnected,
            message: this.t('Connection lost. Trying to reconnect...'),
            duration: reconnectDuration,
          });
          this.disconnectTimeout = setTimeout(() => {
            var _a;
            if (this.states != null) {
              this.states.roomLeftState = 'disconnected';
            }
            state.roomLeftState = 'disconnected';
            (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.leaveRoom();
          }, reconnectDuration);
        }
        else if (event === 'connected') {
          reconnectDuration = 3000;
          this.add({
            id: `network`,
            icon: this.iconPack.wifi,
            message: this.t('Connection restored'),
            duration: reconnectDuration,
          });
          clearTimeout(this.disconnectTimeout);
        }
      };
      const currentDevices = meeting.self.getCurrentDevices();
      if (currentDevices.speaker != null) {
        this.audio.setDevice(currentDevices.speaker.deviceId);
      }
      meeting.participants.joined.addListener('participantJoined', this.participantJoinedListener);
      meeting.participants.joined.addListener('participantLeft', this.participantLeftListener);
      meeting.chat.addListener('chatUpdate', this.chatUpdateListener);
      meeting.polls.addListener('pollsUpdate', this.pollUpdateListener);
      meeting.self.addListener('deviceUpdate', this.deviceUpdateListener);
      meeting.meta.addListener('disconnected', () => this.networkUpdateListener({ event: 'disconnected' }));
      meeting.meta.addListener('connected', () => this.networkUpdateListener({ event: 'connected' }));
      meeting.remote.addListener('remoteUpdate', this.onRemoteUpdate);
    }
  }
  configChanged(config) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p;
    if (config != null) {
      this.notificationPermissions.participant_joined =
        (_b = (_a = config.config) === null || _a === void 0 ? void 0 : _a.notifications) === null || _b === void 0 ? void 0 : _b.includes('participant_joined');
      this.notificationPermissions.participant_left =
        (_d = (_c = config.config) === null || _c === void 0 ? void 0 : _c.notifications) === null || _d === void 0 ? void 0 : _d.includes('participant_left');
      this.notificationPermissions.chat = (_f = (_e = config.config) === null || _e === void 0 ? void 0 : _e.notifications) === null || _f === void 0 ? void 0 : _f.includes('chat');
      this.soundPermissions.participant_joined =
        (_h = (_g = config.config) === null || _g === void 0 ? void 0 : _g.notification_sounds) === null || _h === void 0 ? void 0 : _h.includes('participant_joined');
      this.soundPermissions.participant_left =
        (_k = (_j = config.config) === null || _j === void 0 ? void 0 : _j.notification_sounds) === null || _k === void 0 ? void 0 : _k.includes('participant_left');
      this.soundPermissions.chat = (_m = (_l = config.config) === null || _l === void 0 ? void 0 : _l.notification_sounds) === null || _m === void 0 ? void 0 : _m.includes('chat');
      this.participantChatMessageSoundNotificationLimit =
        (_o = config.config) === null || _o === void 0 ? void 0 : _o.participant_chat_message_sound_notification_limit;
      this.participantJoinedSoundNotificationLimit =
        (_p = config.config) === null || _p === void 0 ? void 0 : _p.participant_joined_sound_notification_limit;
    }
  }
  statesUpdate(states) {
    var _a, _b;
    if (states != null) {
      const notificationSoundsEnabled = !states.prefs.muteNotificationSounds;
      const configSoundPermission = (_b = (_a = this.config) === null || _a === void 0 ? void 0 : _a.config) === null || _b === void 0 ? void 0 : _b.notification_sounds;
      for (const permission in this.soundPermissions) {
        if (configSoundPermission === null || configSoundPermission === void 0 ? void 0 : configSoundPermission.includes(permission)) {
          this.soundPermissions[permission] = notificationSoundsEnabled;
        }
      }
    }
  }
  add(notification) {
    // show notifications only if tab is in focus and a maximum of 5 at a time
    if (document.visibilityState === 'visible' && this.notifications.length < 5) {
      // adds new notification to start of array so they appear at the bottom
      this.notifications = [...this.notifications, notification];
    }
  }
  remove(id) {
    this.notifications = this.notifications.filter((notification) => notification.id !== id);
  }
  handleDismiss(e) {
    e.stopPropagation();
    const id = e.detail;
    const el = this.host.shadowRoot.querySelector(`[data-id="${id}"]`);
    // exit animation
    el === null || el === void 0 ? void 0 : el.classList.add('exit');
    setTimeout(() => {
      writeTask(() => {
        this.remove(id);
      });
    }, 400);
  }
  canPlayParticipantJoinedSound() {
    return (this.participantJoinedSoundNotificationLimit == undefined ||
      this.participantJoinedSoundNotificationLimit <= 0 ||
      this.meeting.participants.count <= this.participantJoinedSoundNotificationLimit);
  }
  canPlayChatSound() {
    return (this.participantChatMessageSoundNotificationLimit == undefined ||
      this.participantChatMessageSoundNotificationLimit <= 0 ||
      this.meeting.participants.count <= this.participantChatMessageSoundNotificationLimit);
  }
  render() {
    return (h(Host, null, this.notifications.map((notification) => (h("dyte-notification", { size: this.size, key: notification.id, "data-id": notification.id, notification: notification, onDyteNotificationDismiss: (e) => this.handleDismiss(e) })))));
  }
  get host() { return this; }
  static get watchers() { return {
    "meeting": ["meetingChanged"],
    "config": ["configChanged"],
    "states": ["statesUpdate"]
  }; }
  static get style() { return dyteNotificationsCss; }
}, [1, "dyte-notifications", {
    "meeting": [16],
    "states": [16],
    "config": [16],
    "t": [16],
    "size": [513],
    "iconPack": [16],
    "notifications": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-notifications", "dyte-button", "dyte-icon", "dyte-notification"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-notifications":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteNotifications$1);
      }
      break;
    case "dyte-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "dyte-notification":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const DyteNotifications = DyteNotifications$1;
const defineCustomElement = defineCustomElement$1;

export { DyteNotifications, defineCustomElement };
